@@ -108,7 +108,6 @@ def _run_grid_search(runner: ExperimentRunner,
         for adjacent_code in _get_adjacent_codes(curr, '.'.join(all_codes)):
             if adjacent_code not in marks:
                 runner.verbose = max(0, verbose - 1)
-                runner.CACHE.RESET(prompt=False)
                 runner.cfg_path = cfg_dict[adjacent_code]
 
                 if verbose > 0:
@@ -117,6 +116,7 @@ def _run_grid_search(runner: ExperimentRunner,
                 if with_preprocess:
                     runner.preprocess()
                 score = runner.run(*args, **kwargs)
+                runner.CACHE.RESET(prompt=False)
                 if verbose > 0:
                     print(score)
 
@@ -130,20 +130,19 @@ def _run_grid_search(runner: ExperimentRunner,
                 cache.SET('score_dict', score_dict)
                 cache.SAVE()
 
+                with open(os.path.join(all_cfg_dir, 'seen_scores.json'), 'w') as f:
+                    json.dump(score_dict, f, indent=4)
+
                 if last_score is None or score > last_score:
                     last_score = score
                     found_more = True
                     curr = adjacent_code
                     break
-
-
-
         if not found_more:
             break
 
-    with open(os.path.join(all_cfg_dir, 'seen_scores.json'), 'w') as f:
-        json.dump(score_dict, f, indent=4)
-
+    if verbose > 0:
+        print(f"Results saved in {os.path.join(all_cfg_dir, 'seen_scores.json')}!")
     return cache
 
 
